@@ -23,6 +23,11 @@
 #include "mmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 /******************************************************************************
 *                                                                             *
 * ja:メニュー関数群                                                           *
@@ -160,4 +165,9 @@ command_charset (gpointer   callback_data,
                  GtkWidget *widget);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
