@@ -23,16 +23,27 @@
 #include "mmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 /******************************************************************************
 *                                                                             *
 * ja:リロードダイアログ関数群                                                 *
 *                                                                             *
 ******************************************************************************/
-
-
+/*  ja:リロードダイアログ表示
+    mmaid,ウインドウ情報
+     text,説明文(Yes/No),NULL:説明なし(OK/Cansel)                           */
 gboolean
 reload_dialog (MmaidWindow *mmaid,
                const gchar *text);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
